@@ -13,6 +13,7 @@ from typing import Any, Dict, List, Optional
 import stytch
 
 from ..cache.redis_client import redis_client
+from ..db.entitlements_loader import entitlements_loader
 from ..models.context import StytchContext
 from ..utils.config import settings
 from ..utils.exceptions import StytchAPIError, TokenVerificationError
@@ -52,7 +53,6 @@ class StytchVerifier:
                     secret=settings.secret,
                     environment=settings.environment,
                 )
-                logger.info("Stytch B2B client initialized successfully")
             except Exception as e:
                 logger.error(f"Failed to initialize Stytch client: {str(e)}")
                 raise StytchAPIError(f"Stytch client initialization failed: {str(e)}")
@@ -90,15 +90,18 @@ class StytchVerifier:
         # Try cache first
         cached_result = await self._get_cached_verification(token_hash)
         if cached_result:
-            return self._build_context_from_cache(cached_result)
+            return await self._build_context_from_cache(cached_result)
 
         # Fall back to Stytch API
         session_data = await self._verify_with_stytch_api(token)
 
-        # Cache the result
-        await self._cache_verification_result(token_hash, session_data)
+        # Build context with entitlements (v2.0.0+)
+        stytch_context = await self._build_context_from_stytch_data(session_data)
 
-        return self._build_context_from_stytch_data(session_data)
+        # Cache the complete result (including entitlements)
+        await self._cache_verification_result(token_hash, stytch_context)
+
+        return stytch_context
 
     async def _get_cached_verification(
         self, token_hash: str
@@ -146,63 +149,13 @@ class StytchVerifier:
         Raises:
             TokenVerificationError: If token is invalid
             StytchAPIError: If API call fails
-
-        Note:
-            This method contains extensive debug logging (marked with 🔍 [DEBUG])
-            to help diagnose response parsing issues. This logging should be
-            removed or reduced in a future release once the parsing issues
-            are fully resolved.
         """
         try:
             client = self._get_client()
 
             logger.debug("Verifying token with Stytch API")
-            logger.debug(
-                f"🔍 [DEBUG] Starting Stytch API verification (token: {token[:8]}...)"
-            )
             response = client.sessions.authenticate(session_token=token)
 
-            # Enhanced debug logging for response analysis
-            logger.debug(f"🔍 [DEBUG] Response type: {type(response)}")
-            logger.debug(f"🔍 [DEBUG] Response class: {response.__class__}")
-            logger.debug(
-                f"🔍 [DEBUG] Response status_code: {getattr(response, 'status_code', 'N/A')}"
-            )
-            logger.debug(
-                f"🔍 [DEBUG] Response has json method: {hasattr(response, 'json')}"
-            )
-            logger.debug(
-                f"🔍 [DEBUG] Response has __dict__: {hasattr(response, '__dict__')}"
-            )
-            logger.debug(
-                f"🔍 [DEBUG] Response has member_session attr: {hasattr(response, 'member_session')}"
-            )
-            logger.debug(
-                f"🔍 [DEBUG] Response has member attr: {hasattr(response, 'member')}"
-            )
-            logger.debug(
-                f"🔍 [DEBUG] Response isinstance str: {isinstance(response, str)}"
-            )
-            logger.debug(
-                f"🔍 [DEBUG] Response isinstance dict: {isinstance(response, dict)}"
-            )
-
-            # Log response attributes for debugging
-            if hasattr(response, "__dict__"):
-                logger.debug(
-                    f"🔍 [DEBUG] Response __dict__ keys: {list(response.__dict__.keys())}"
-                )
-
-            # Log first 300 chars of string representation
-            response_str_preview = str(response)[:300]
-            logger.debug(f"🔍 [DEBUG] Response str preview: {response_str_preview}")
-            logger.debug(
-                f"🔍 [DEBUG] Response str starts with {{: {str(response).startswith('{')}"
-            )
-            logger.debug(
-                f"🔍 [DEBUG] Response str ends with }}: {str(response).endswith('}')}"
-            )
-
             if hasattr(response, "status_code") and response.status_code != 200:
                 logger.warning(
                     f"Stytch API returned error: {response.status_code}",
@@ -220,74 +173,37 @@ class StytchVerifier:
 
             # Handle different response formats from Stytch SDK
             session_data = None
-            parsing_path = "unknown"
 
             # First, try to convert response to string to check if it's JSON
             response_str = str(response)
-            logger.debug(
-                f"🔍 [DEBUG] Response string representation: {response_str[:200]}..."
-            )
 
             if hasattr(response, "json") and callable(response.json):
                 # Response is an HTTP response object
-                parsing_path = "http_response_json_method"
-                logger.debug(f"🔍 [DEBUG] Attempting parsing path: {parsing_path}")
                 try:
                     session_data = response.json()
-                    logger.debug("🔍 [DEBUG] ✅ Successfully called .json() method")
-                    logger.debug(
-                        f"🔍 [DEBUG] .json() returned type: {type(session_data)}"
-                    )
 
                     # Check if .json() returned a string instead of parsed data
                     if isinstance(session_data, str):
-                        logger.debug(
-                            "🔍 [DEBUG] .json() returned string, parsing as JSON"
-                        )
                         session_data = json.loads(session_data)
-                        logger.debug(
-                            "🔍 [DEBUG] ✅ Successfully parsed JSON string from .json() method"
-                        )
-                        logger.debug(
-                            f"🔍 [DEBUG] Final parsed data type: {type(session_data)}"
-                        )
-                    else:
-                        logger.debug("🔍 [DEBUG] .json() returned parsed data directly")
 
-                except Exception as e:
-                    logger.error(
-                        f"🔍 [DEBUG] ❌ Failed to parse using .json() method: {e}"
-                    )
+                except Exception:
                     session_data = None
             elif isinstance(response, dict):
                 # Response is already a dictionary
-                parsing_path = "already_dict"
-                logger.debug(f"🔍 [DEBUG] Attempting parsing path: {parsing_path}")
                 session_data = response
-                logger.debug("🔍 [DEBUG] ✅ Response is already a dictionary")
-                logger.debug(f"🔍 [DEBUG] Dict keys: {list(session_data.keys())}")
             elif hasattr(response, "member_session") and hasattr(response, "member"):
                 # Modern Stytch response object with direct attributes
-                parsing_path = "stytch_object_direct_attrs"
-                logger.debug(f"🔍 [DEBUG] Attempting parsing path: {parsing_path}")
                 member_session = getattr(response, "member_session", {})
                 member = getattr(response, "member", {})
                 organization = getattr(response, "organization", {})
 
-                logger.debug(f"🔍 [DEBUG] member_session type: {type(member_session)}")
-                logger.debug(f"🔍 [DEBUG] member type: {type(member)}")
-                logger.debug(f"🔍 [DEBUG] organization type: {type(organization)}")
-
                 # Convert objects to dicts if they're not already
                 if hasattr(member_session, "__dict__"):
                     member_session = member_session.__dict__
-                    logger.debug("🔍 [DEBUG] Converted member_session to dict")
                 if hasattr(member, "__dict__"):
                     member = member.__dict__
-                    logger.debug("🔍 [DEBUG] Converted member to dict")
                 if hasattr(organization, "__dict__"):
                     organization = organization.__dict__
-                    logger.debug("🔍 [DEBUG] Converted organization to dict")
 
                 session_data = {
                     "status_code": getattr(response, "status_code", 200),
@@ -298,132 +214,49 @@ class StytchVerifier:
                     "session_token": getattr(response, "session_token", ""),
                     "session_jwt": getattr(response, "session_jwt", ""),
                 }
-                logger.debug(
-                    "🔍 [DEBUG] ✅ Converted Stytch response object to dict using direct attributes"
-                )
-                logger.debug(
-                    f"🔍 [DEBUG] Final session_data keys: {list(session_data.keys())}"
-                )
             elif response_str.startswith("{") and response_str.endswith("}"):
                 # Response looks like JSON - try to parse it
-                parsing_path = "json_string_from_str_repr"
-                logger.debug(f"🔍 [DEBUG] Attempting parsing path: {parsing_path}")
-                logger.debug(f"🔍 [DEBUG] JSON string length: {len(response_str)}")
                 try:
                     session_data = json.loads(response_str)
-                    logger.debug(
-                        "🔍 [DEBUG] ✅ Parsed response as JSON string from string representation"
-                    )
-                    logger.debug(f"🔍 [DEBUG] Parsed data type: {type(session_data)}")
-                    logger.debug(
-                        f"🔍 [DEBUG] Parsed data keys: {list(session_data.keys()) if isinstance(session_data, dict) else 'N/A'}"
-                    )
                 except json.JSONDecodeError as e:
-                    logger.error(
-                        f"🔍 [DEBUG] ❌ Failed to parse JSON string response: {e}"
-                    )
-                    logger.error(
-                        f"🔍 [DEBUG] Raw response content: {response_str[:500]}..."
-                    )
                     raise StytchAPIError(
                         "Invalid JSON response from Stytch API",
                         api_response={"error": f"JSON parse error: {str(e)}"},
                     )
             elif isinstance(response, str):
                 # Response is a JSON string - parse it
-                parsing_path = "direct_string_instance"
-                logger.debug(f"🔍 [DEBUG] Attempting parsing path: {parsing_path}")
-                logger.debug(f"🔍 [DEBUG] String length: {len(response)}")
                 try:
                     session_data = json.loads(response)
-                    logger.debug("🔍 [DEBUG] ✅ Parsed response as JSON string")
-                    logger.debug(f"🔍 [DEBUG] Parsed data type: {type(session_data)}")
-                    logger.debug(
-                        f"🔍 [DEBUG] Parsed data keys: {list(session_data.keys()) if isinstance(session_data, dict) else 'N/A'}"
-                    )
                 except json.JSONDecodeError as e:
-                    logger.error(
-                        f"🔍 [DEBUG] ❌ Failed to parse JSON string response: {e}"
-                    )
-                    logger.error(
-                        f"🔍 [DEBUG] Raw response content: {response[:500]}..."
-                    )
                     raise StytchAPIError(
                         "Invalid JSON response from Stytch API",
                         api_response={"error": f"JSON parse error: {str(e)}"},
                     )
             elif hasattr(response, "__dict__"):
                 # Response is a Stytch response object - convert to dict
-                parsing_path = "generic_object_dict"
-                logger.debug(f"🔍 [DEBUG] Attempting parsing path: {parsing_path}")
                 session_data = response.__dict__
-                logger.debug(
-                    "🔍 [DEBUG] ✅ Converted response object to dict using __dict__"
-                )
-                logger.debug(f"🔍 [DEBUG] Dict keys: {list(session_data.keys())}")
             else:
                 # Response is some other format - try to get its attributes
-                parsing_path = "fallback_vars"
-                logger.debug(f"🔍 [DEBUG] Attempting parsing path: {parsing_path}")
-                logger.warning(
-                    f"🔍 [DEBUG] ⚠️ Unexpected response format: {type(response)}"
-                )
-                logger.debug(f"🔍 [DEBUG] Response content: {response_str[:200]}...")
                 session_data = vars(response) if hasattr(response, "__dict__") else {}
-                logger.debug(f"🔍 [DEBUG] Fallback session_data: {session_data}")
 
             # Final validation and logging
-            logger.debug("🔍 [DEBUG] Final parsing result:")
-            logger.debug(f"🔍 [DEBUG] - Parsing path used: {parsing_path}")
-            logger.debug(f"🔍 [DEBUG] - Session data type: {type(session_data)}")
-            logger.debug(f"🔍 [DEBUG] - Session data is None: {session_data is None}")
 
             # Validate we have the expected data structure
             if not isinstance(session_data, dict):
-                logger.error(
-                    "🔍 [DEBUG] ❌ VALIDATION FAILED: Session data is not a dict"
-                )
-                logger.error(f"🔍 [DEBUG] - Session data type: {type(session_data)}")
-                logger.error(
-                    f"🔍 [DEBUG] - Session data content: {str(session_data)[:200]}..."
-                )
-                logger.error(f"🔍 [DEBUG] - Parsing path used: {parsing_path}")
-                logger.error(f"🔍 [DEBUG] - Original response type: {type(response)}")
-                logger.error(
-                    f"🔍 [DEBUG] - Original response class: {response.__class__}"
-                )
                 raise StytchAPIError(
                     "Invalid response format from Stytch API",
                     api_response={"error": f"Expected dict, got {type(session_data)}"},
                 )
 
-            logger.debug("🔍 [DEBUG] ✅ Session data validation passed - type is dict")
-            logger.debug(f"🔍 [DEBUG] Session data keys: {list(session_data.keys())}")
-
             # Check for required fields in the response
             # Stytch B2B API returns member_session instead of separate member/session
             if "member_session" not in session_data or "member" not in session_data:
-                logger.error(
-                    "🔍 [DEBUG] ❌ FIELD VALIDATION FAILED: Missing required fields"
-                )
-                logger.error(
-                    f"🔍 [DEBUG] - Available keys: {list(session_data.keys())}"
-                )
-                logger.error(
-                    f"🔍 [DEBUG] - Has member_session: {'member_session' in session_data}"
-                )
-                logger.error(f"🔍 [DEBUG] - Has member: {'member' in session_data}")
-                logger.error(f"🔍 [DEBUG] - Parsing path used: {parsing_path}")
                 raise StytchAPIError(
                     "Invalid session data format from Stytch API",
                     api_response={"error": "Missing member_session or member data"},
                 )
 
-            logger.debug("🔍 [DEBUG] ✅ Required fields validation passed")
             logger.info("Token verified successfully with Stytch API")
-            logger.debug(
-                f"🔍 [DEBUG] 🎉 Complete success - returning session data with {len(session_data)} keys"
-            )
             return session_data
 
         except TokenVerificationError:
@@ -431,6 +264,7 @@ class StytchVerifier:
             raise
 
         except Exception as e:
+            # Log configuration details when API calls fail to help diagnose environment issues
             logger.error(f"Stytch API verification failed: {str(e)}", exc_info=True)
             raise StytchAPIError(
                 f"Failed to verify token with Stytch: {str(e)}",
@@ -438,62 +272,55 @@ class StytchVerifier:
             )
 
     async def _cache_verification_result(
-        self, token_hash: str, session_data: Dict[str, Any]
+        self, token_hash: str, context: StytchContext
     ) -> None:
         """
-        Cache verification result for future use.
+        Cache verification result with entitlements for future use.
 
         Args:
             token_hash: Hash of the verified token
-            session_data: Session data from Stytch API
+            context: Complete StytchContext with all session and entitlements data
         """
         try:
-            # Extract essential data for caching
-            # Handle both dict and object formats from Stytch SDK
-            member_data = session_data.get("member", {})
-            session_data_inner = session_data.get("member_session", {})
-            organization_data = session_data.get("organization", {})
-
-            # Helper function to safely get attribute from object or dict
-            def safe_get(obj: Any, attr: str, default: Any = None) -> Any:
-                if hasattr(obj, attr):
-                    return getattr(obj, attr)
-                elif isinstance(obj, dict):
-                    return obj.get(attr, default)
-                return default
-
-            # Normalize authentication factors for caching
-            raw_auth_factors = safe_get(
-                session_data_inner, "authentication_factors", []
-            )
-            normalized_factors = []
-            for factor in raw_auth_factors:
-                if isinstance(factor, dict):
-                    factor_type = factor.get("type", "unknown")
-                    normalized_factors.append(factor_type)
-                elif isinstance(factor, str):
-                    normalized_factors.append(factor)
-                else:
-                    normalized_factors.append(str(factor))
-
+            # Convert StytchContext to cacheable dict
+            # Note: Team context (current_team_id, current_team_name) is NOT cached
+            # to ensure it's always fresh from MongoDB
             cache_data = {
-                "member_id": safe_get(member_data, "member_id")
-                or safe_get(session_data_inner, "member_id"),
-                "session_id": safe_get(session_data_inner, "member_session_id"),
-                "organization_id": safe_get(organization_data, "organization_id")
-                or safe_get(session_data_inner, "organization_id"),
-                "session_started_at": safe_get(session_data_inner, "started_at"),
-                "session_expires_at": safe_get(session_data_inner, "expires_at"),
-                "session_last_accessed_at": safe_get(
-                    session_data_inner, "last_accessed_at"
+                # Core Stytch identifiers
+                "member_id": context.member_id,
+                "session_id": context.session_id,
+                "organization_id": context.organization_id,
+                # Session timing
+                "session_started_at": (
+                    context.session_started_at.isoformat()
+                    if context.session_started_at
+                    else None
                 ),
-                "member_email": safe_get(member_data, "email_address"),
-                "member_name": safe_get(member_data, "name"),
-                "session_custom_claims": safe_get(
-                    session_data_inner, "custom_claims", {}
+                "session_expires_at": (
+                    context.session_expires_at.isoformat()
+                    if context.session_expires_at
+                    else None
                 ),
-                "authentication_factors": normalized_factors,
-                "raw_session_data": session_data,
+                "session_last_accessed_at": (
+                    context.session_last_accessed_at.isoformat()
+                    if context.session_last_accessed_at
+                    else None
+                ),
+                # Member information
+                "member_email": context.member_email,
+                "member_name": context.member_name,
+                # Session metadata
+                "session_custom_claims": context.session_custom_claims,
+                "authentication_factors": context.authentication_factors,
+                "raw_session_data": context.raw_session_data,
+                # Entitlements and subscription (v2.0.0+)
+                "entitlements": context.entitlements,
+                "subscription_tier": context.subscription_tier,
+                "subscription_limits": context.subscription_limits,
+                # MongoDB identifiers (v2.0.0+)
+                "mongo_user_id": context.mongo_user_id,
+                "mongo_organization_id": context.mongo_organization_id,
+                # Cache metadata
                 "cached_at": datetime.now(timezone.utc).isoformat(),
             }
 
@@ -503,25 +330,50 @@ class StytchVerifier:
             logger.warning(f"Failed to cache verification result: {str(e)}")
             # Don't raise - caching failures should be non-fatal
 
-    def _build_context_from_cache(self, cached_data: Dict[str, Any]) -> StytchContext:
+    async def _build_context_from_cache(
+        self, cached_data: Dict[str, Any]
+    ) -> StytchContext:
         """
         Build StytchContext from cached verification data.
 
+        Team context is loaded fresh from MongoDB on every request to ensure
+        current_team_id and current_team_name are always up-to-date.
+
         Args:
-            cached_data: Cached session data
+            cached_data: Cached session data (includes entitlements if available)
 
         Returns:
-            StytchContext instance
+            StytchContext instance with fresh team context
         """
         # Handle datetime fields safely
         started_at = cached_data.get("session_started_at")
         expires_at = cached_data.get("session_expires_at")
         last_accessed_at = cached_data.get("session_last_accessed_at")
 
+        # Load fresh team context from MongoDB (not cached)
+        member_id = cached_data["member_id"]
+        organization_id = cached_data.get("organization_id")  # Get org ID from cache
+        team_context = {}
+        if settings.mongodb_uri and member_id:
+            try:
+                # Pass organization_id for multi-org user support
+                team_context = (
+                    await entitlements_loader.load_user_context(
+                        member_id, organization_id
+                    )
+                    or {}
+                )
+            except Exception as e:
+                logger.warning(
+                    f"Failed to load fresh team context from cache: {str(e)}"
+                )
+
         return StytchContext(
-            member_id=cached_data["member_id"],
+            # Core Stytch identifiers
+            member_id=member_id,
             session_id=cached_data["session_id"],
             organization_id=cached_data["organization_id"],
+            # Session timing
             session_started_at=(
                 datetime.fromisoformat(started_at)
                 if started_at
@@ -537,24 +389,39 @@ class StytchVerifier:
                 if last_accessed_at
                 else datetime.now(timezone.utc)
             ),
+            # Member information
             member_email=cached_data.get("member_email"),
             member_name=cached_data.get("member_name"),
+            # Session metadata
             session_custom_claims=cached_data.get("session_custom_claims", {}),
             authentication_factors=cached_data.get("authentication_factors", []),
             raw_session_data=cached_data.get("raw_session_data", {}),
+            # Entitlements and subscription (v2.0.0+ - may be None for old cache entries)
+            entitlements=cached_data.get("entitlements"),
+            subscription_tier=cached_data.get("subscription_tier"),
+            subscription_limits=cached_data.get("subscription_limits"),
+            # Team context (v2.0.1+ - always loaded fresh from MongoDB)
+            current_team_id=team_context.get("current_team_id"),
+            current_team_name=team_context.get("current_team_name"),
+            # MongoDB identifiers (v2.0.0+ - may be None for old cache entries)
+            mongo_user_id=team_context.get("mongo_user_id")
+            or cached_data.get("mongo_user_id"),
+            mongo_organization_id=cached_data.get("mongo_organization_id"),
         )
 
-    def _build_context_from_stytch_data(
+    async def _build_context_from_stytch_data(
         self, session_data: Dict[str, Any]
     ) -> StytchContext:
         """
         Build StytchContext from fresh Stytch API response.
 
+        Loads entitlements and team context from MongoDB if configured.
+
         Args:
             session_data: Raw session data from Stytch API
 
         Returns:
-            StytchContext instance
+            StytchContext instance with entitlements and team data
         """
         # Handle both dict and object formats from Stytch SDK
         member = session_data.get("member", {})
@@ -581,20 +448,13 @@ class StytchVerifier:
                     # Extract the type from the dict or use a fallback
                     factor_type = factor.get("type", "unknown")
                     normalized.append(factor_type)
-                    logger.debug(
-                        f"🔍 [DEBUG] Normalized auth factor dict to string: {factor_type}"
-                    )
                 elif isinstance(factor, str):
                     # Already a string, keep as-is
                     normalized.append(factor)
                 else:
                     # Fallback for unexpected types
                     normalized.append(str(factor))
-                    logger.debug(
-                        f"🔍 [DEBUG] Converted auth factor to string: {str(factor)}"
-                    )
 
-            logger.debug(f"🔍 [DEBUG] Final normalized auth factors: {normalized}")
             return normalized
 
         # Handle datetime fields safely
@@ -604,20 +464,42 @@ class StytchVerifier:
 
         # Get and normalize authentication factors
         raw_auth_factors = safe_get(session, "authentication_factors", [])
-        logger.debug(f"🔍 [DEBUG] Raw auth factors: {raw_auth_factors}")
-        logger.debug(f"🔍 [DEBUG] Raw auth factors type: {type(raw_auth_factors)}")
-        if raw_auth_factors:
-            logger.debug(
-                f"🔍 [DEBUG] First auth factor type: {type(raw_auth_factors[0])}"
-            )
-            logger.debug(f"🔍 [DEBUG] First auth factor content: {raw_auth_factors[0]}")
         normalized_auth_factors = normalize_auth_factors(raw_auth_factors)
 
+        # Extract core identifiers
+        member_id = safe_get(member, "member_id") or safe_get(session, "member_id")
+        organization_id = safe_get(organization, "organization_id") or safe_get(
+            session, "organization_id"
+        )
+
+        # Load entitlements and team context (v2.0.0+)
+        # This is optional - if MongoDB is not configured, all fields will be None
+        entitlements_data = {}
+        if settings.mongodb_uri and member_id and organization_id:
+            try:
+                logger.debug(
+                    f"Loading entitlements for org: {organization_id}, member: {member_id}"
+                )
+                entitlements_data = (
+                    await entitlements_loader.load_complete_session_data(
+                        stytch_org_id=organization_id,
+                        stytch_member_id=member_id,
+                    )
+                )
+                logger.debug(f"Entitlements data loaded: {bool(entitlements_data)}")
+            except Exception as e:
+                logger.warning(
+                    f"Failed to load entitlements data: {str(e)}. "
+                    f"Continuing without entitlements."
+                )
+                entitlements_data = {}
+
         return StytchContext(
-            member_id=safe_get(member, "member_id") or safe_get(session, "member_id"),
+            # Core Stytch identifiers
+            member_id=member_id,
             session_id=safe_get(session, "member_session_id"),
-            organization_id=safe_get(organization, "organization_id")
-            or safe_get(session, "organization_id"),
+            organization_id=organization_id,
+            # Session timing
             session_started_at=(
                 datetime.fromisoformat(started_at)
                 if started_at
@@ -633,34 +515,64 @@ class StytchVerifier:
                 if last_accessed_at
                 else datetime.now(timezone.utc)
             ),
+            # Member information
             member_email=safe_get(member, "email_address"),
             member_name=safe_get(member, "name"),
+            # Session metadata
             session_custom_claims=safe_get(session, "custom_claims", {}),
             authentication_factors=normalized_auth_factors,
             raw_session_data=session_data,
+            # Entitlements and subscription (v2.0.0+)
+            entitlements=entitlements_data.get("entitlements"),
+            subscription_tier=entitlements_data.get("subscription_tier"),
+            subscription_limits=entitlements_data.get("subscription_limits"),
+            # Team context (v2.0.0+)
+            current_team_id=entitlements_data.get("current_team_id"),
+            current_team_name=entitlements_data.get("current_team_name"),
+            # MongoDB identifiers (v2.0.0+)
+            mongo_user_id=entitlements_data.get("mongo_user_id"),
+            mongo_organization_id=entitlements_data.get("mongo_organization_id"),
         )
 
-    async def get_member_by_email(self, email: str) -> Optional[Dict[str, Any]]:
+    async def get_member_by_email(
+        self, email: str, organization_id: str
+    ) -> Optional[Dict[str, Any]]:
         """
-        Get a member's details by their email address.
-        This is needed to resolve an email to a Stytch member ID, which is used
-        to add a user to a project in the soulmates-file-management service.
-        """
-        logger.info(f"Attempting to get member by email: {email}")
+        Get a member's details by their email address within a specific organization.
 
-        if not settings.organization_id:
-            raise StytchAPIError(
-                "Organization ID is required for member search operations. "
-                "Please set STYTCH_ORGANIZATION_ID environment variable."
-            )
+        This is needed to resolve an email to a Stytch member ID, which can be used
+        to add a user to a project or perform other user management operations.
+
+        Args:
+            email: Email address to search for
+            organization_id: Stytch organization ID (from authenticated user's context)
+
+        Returns:
+            Member data dict if found, None otherwise
+
+        Raises:
+            StytchAPIError: If the Stytch API call fails
+
+        Example:
+            # Get organization_id from authenticated user's session
+            @app.post("/invite-member")
+            async def invite_member(
+                email: str,
+                user: StytchContext = Depends(verify_auth)
+            ):
+                # Use the authenticated user's organization
+                member = await stytch_verifier.get_member_by_email(
+                    email, user.organization_id
+                )
+        """
+        logger.info(
+            f"Attempting to get member by email: {email} in org: {organization_id}"
+        )
 
         try:
             client = self._get_client()
-            # Note: This requires the organization ID to be set in the config.
-            # This is a temporary solution until a more robust user management
-            # service is in place.
             response = client.organizations.members.search(
-                organization_ids=[settings.organization_id],
+                organization_ids=[organization_id],
                 query={
                     "operator": "AND",
                     "operands": [
@@ -699,9 +611,12 @@ class StytchVerifier:
             return None
 
         except StytchAPIError as e:
+            extra = {}
+            if hasattr(e, "details") and e.details is not None:
+                extra = {"api_response": e.details.get("api_response")}
             logger.error(
                 f"Stytch API search for member failed: {e.message}",
-                extra={"api_response": e.details.get("api_response")},
+                extra=extra,
             )
             raise  # Re-raise the exception to be handled by the endpoint
         except Exception as e:
